@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -12,6 +12,6 @@
 
 """ Qiskit Nature test packages """
 
-from .nature_test_case import QiskitNatureTestCase, requires_extra_library
+from .nature_test_case import QiskitNatureTestCase
 
-__all__ = ["QiskitNatureTestCase", "requires_extra_library"]
+__all__ = ["QiskitNatureTestCase"]
