@@ -104,3 +104,37 @@ class TestPUCC(QiskitNatureTestCase):
         """Test an error is raised when the number of alpha and beta electrons differ."""
         with self.assertRaises(QiskitNatureError):
             PUCCD(num_particles=(2, 1))
+
+    @unpack
+    @data(
+        (
+            6,
+            (1, 1),
+            [
+                FermionicOp([("+-I+-I", 1j), ("-+I-+I", -1j)], display_format="dense"),
+                FermionicOp([("+I-+I-", 1j), ("-I+-I+", -1j)], display_format="dense"),
+                FermionicOp([("I+-I+-", 1j), ("I-+I-+", -1j)], display_format="dense"),
+            ],
+        ),
+        (
+            6,
+            (2, 2),
+            [
+                FermionicOp([("+-I+-I", 1j), ("-+I-+I", -1j)], display_format="dense"),
+                FermionicOp([("+I-+I-", 1j), ("-I+-I+", -1j)], display_format="dense"),
+                FermionicOp([("I+-I+-", 1j), ("I-+I-+", -1j)], display_format="dense"),
+            ],
+        ),
+    )
+    def test_puccd_ansatz_generalized(self, num_spin_orbitals, num_particles, expect):
+        """Tests the generalized PUCCD Ansatz."""
+        converter = QubitConverter(JordanWignerMapper())
+
+        ansatz = PUCCD(
+            qubit_converter=converter,
+            num_particles=num_particles,
+            num_spin_orbitals=num_spin_orbitals,
+            generalized=True,
+        )
+
+        assert_ucc_like_ansatz(self, ansatz, num_spin_orbitals, expect)
