@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -40,7 +40,7 @@ class TestEnd2End(QiskitNatureTestCase):
             )
         )
         problem = ElectronicStructureProblem(driver)
-        second_q_ops = problem.second_q_ops()
+        second_q_ops = [problem.second_q_ops()[problem.main_property_name]]
         converter = QubitConverter(mapper=ParityMapper(), two_qubit_reduction=True)
         num_particles = (
             problem.grouped_property_transformed.get_property("ParticleNumber").num_alpha,
